@@ -55,7 +55,7 @@ impl App {
         if let Some(event) = user_event {
             match event {
                 UserEvent::ImageLoaded(image, path) => {
-                    self.image_view = Some(ImageView::new(display, image.clone()));
+                    self.image_view = Some(ImageView::new(display, image.clone(), path.clone()));
                     let view = self.image_view.as_mut().unwrap();
                     self.current_filename = path.file_name().unwrap().to_str().unwrap().to_string();
 
@@ -123,9 +123,15 @@ impl App {
                                 VirtualKeyCode::S => {
                                     move_image(&mut self.image_view, Vec2::new(0.0, 20.0))
                                 }
-
+                                
                                 VirtualKeyCode::Q => rotate_image(&mut self.image_view, 90.0),
                                 VirtualKeyCode::E => rotate_image(&mut self.image_view, -90.0),
+                                
+                                VirtualKeyCode::R => {
+                                    if let Some(image) = self.image_view.as_ref() {
+                                        load_image(self.proxy.clone(), &image.path);
+                                    }
+                                },
 
                                 VirtualKeyCode::F11 => {
                                     let window_context = display.gl_window();
@@ -251,6 +257,15 @@ impl App {
 
             ui.menu(im_str!("Image"), self.image_view.is_some(), || {
                 if let Some(image) = self.image_view.as_mut() {
+                    if MenuItem::new(im_str!("Refresh"))
+                        .shortcut(im_str!("R"))
+                        .build(&ui)
+                    {
+                        load_image(self.proxy.clone(), &image.path);
+                    }
+
+                    ui.separator();
+
                     if MenuItem::new(im_str!("Rotate Left"))
                         .shortcut(im_str!("Q"))
                         .build(&ui)
@@ -298,9 +313,13 @@ impl App {
             StyleVar::WindowPadding([10.0, 4.0]),
             StyleVar::FramePadding([0.0, 0.0]),
             StyleVar::ItemSpacing([0.0, 0.0]),
+            StyleVar::ButtonTextAlign([0.0, 0.5]),
         ]);
 
-        let c = ui.push_style_colors(&[(StyleColor::WindowBg, [0.141, 0.141, 0.141, 1.0])]);
+        let c = ui.push_style_colors(&[
+            (StyleColor::WindowBg, [0.141, 0.141, 0.141, 1.0]),
+            (StyleColor::Button, [0.141, 0.141, 0.141, 1.0]),
+        ]);
 
         Window::new(im_str!("Bottom"))
             .position([0.0, self.size.y() - BOTTOM_BAR_SIZE], Condition::Always)
@@ -312,13 +331,19 @@ impl App {
             .focus_on_appearing(false)
             .always_use_window_padding(true)
             .build(ui, || {
-                if let Some(image) = self.image_view.as_ref() {
+                if let Some(image) = self.image_view.as_mut() {
                     ui.same_line_with_spacing(0.0, 10.0);
                     ui.text(&self.current_filename);
                     ui.same_line_with_spacing(0.0, 20.0);
                     ui.text(&format!("{} x {}", image.size.x(), image.size.y()));
                     ui.same_line_with_spacing(0.0, 20.0);
                     ui.text(&format!("Zoom: {}%", (image.scale * 100.0).round()));
+                    if ui.is_item_clicked(MouseButton::Left) {
+                        image.scale = 1.0;
+                    }
+                } else {
+                    ui.same_line_with_spacing(0.0, 10.0);
+                    ui.text("No File");
                 }
             });
 
